#
# Comorbidity.R
# Author:  Brian Bauer (bbu@qlik.com)
# Date:    September, 2017
# Purpose: Demonstrate a simple Qlik AAI (Advanced Analytics Integration)/SSE (Server-side Extension) using R to score multiple patients records for Comorbidity during the Qlik data load process.
#		   Useful for applications including LACE (Length of Stay [LOS] - Acuity - Comorbidity - ED visits) readmission predictions for the healthcare setting.
#		   Applies to Qlik Sense June 2017 and greater and QlikView November 2017 and greater.
#
#
# 1) library(medicalrisk);
# 2) write.csv(
# 3) 	generate_charlson_index_df(
# 4) 		generate_comorbidity_df(
# 5) 			read.csv(q$inputFile,fileEncoding=q$fileEncoding)
#		  )
#	  )
# 6) ,file=q$outputFile);
#
#
# R code walkthrough...
#
# Line 1: Invoke the medicalrisk R package. Ensure the medicalrisk package is installed in the R console:  install.packages("medicalrisk").
# Line 2: Lines 2-6 are nested R functions.  Line 2 writes out (write.csv) the resulting Comorbidity (Charlson) data frame - one row per patient to an output file (outputFile variable passed in by Qlik parameter).
# Line 3: Function generate_charlson_index_df - takes the output of generate_comorbidity_df and sums the weights (comorbidity flags) for each patient to generate a final Comorbidity (Charlson) index.
# Line 4: Function generate_comorbidity_df - takes the input file (multiple rows per patient with a ICD-9-CM diagnosis or procedure code) and creates a data frame for each patient ID and 17 or so comorbidity flags (TRUE or FALSE) for each one.
# Line 5: Reads the input file for generate_comorbidity_df with the proper file encoding (set by variable fileEncoding='UTF-8-BOM' passed in from Qlik parameter).
# Line 6: Output file (outputFile variable from Qlik parameter) for the write.csv function in line 2.
#
#

library(medicalrisk);
write.csv(
	generate_charlson_index_df(
		generate_comorbidity_df(
			read.csv(q$inputFile,fileEncoding=q$fileEncoding)
		)
	)
,file=q$outputFile);
